Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2326)

Unified Diff: ash/common/shelf/overflow_button.h

Issue 2679133003: [ash-md] Wired in the Shelf color to be derived from the Wallpaper. (Closed)
Patch Set: Addressed nits. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/shelf/overflow_bubble_view.cc ('k') | ash/common/shelf/overflow_button.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/shelf/overflow_button.h
diff --git a/ash/common/shelf/overflow_button.h b/ash/common/shelf/overflow_button.h
index 0e1617a4cc80374431a976f632deefc84e2e3ef4..503811de782446b416be8036a0647755f0b7440c 100644
--- a/ash/common/shelf/overflow_button.h
+++ b/ash/common/shelf/overflow_button.h
@@ -24,8 +24,8 @@ class OverflowButton : public views::CustomButton {
void OnOverflowBubbleShown();
void OnOverflowBubbleHidden();
- // Sets alpha value of the background and schedules a paint.
- void SetBackgroundAlpha(int alpha);
+ // Updates background and schedules a paint.
+ void UpdateShelfItemBackground(SkColor color);
private:
// views::CustomButton:
@@ -66,8 +66,8 @@ class OverflowButton : public views::CustomButton {
ShelfView* shelf_view_;
WmShelf* wm_shelf_;
- // Alpha value used to paint the background.
- int background_alpha_;
+ // Color used to paint the background.
+ SkColor background_color_;
DISALLOW_COPY_AND_ASSIGN(OverflowButton);
};
« no previous file with comments | « ash/common/shelf/overflow_bubble_view.cc ('k') | ash/common/shelf/overflow_button.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698